function addFactorHandlerConfig(dfg)
  function run(msg)
    @info "[ADD FACTOR] START $(msg["userId"]):$(msg["robotId"]):$(msg["sessionId"])"
    assignDfg(dfg,msg["userId"],msg["robotId"],msg["sessionId"])
    unpackedFactor = unpackFactor(dfg, JSON2.read(msg["packedData"], Dict{String, Any}))
    f1 = updateFactor!(dfg, unpackedFactor)
    rebuildFactorMetadata!(dfg, f1)
    @info "[ADD FACTOR] END $(msg["userId"]):$(msg["robotId"]):$(msg["sessionId"])"
  end

  return HandlerConfig(
      "queue-add-factor",
      "topic-add-factor",
      "Add:Factor",
      run
  )
end


function testAddScatterAlignPose2()
    # Assemble packed factor
    testVariableOneLabel::Symbol = Symbol("testVariableOneLabel")
    testVariableTwoLabel::Symbol = Symbol("testVariableTwoLabel")
    testLabel::Symbol = Symbol(String(testVariableOneLabel)*String(testVariableTwoLabel)*"f1")
    dummyDfg::AbstractDFG = initfg()
    addVariable!(dummyDfg, testVariableOneLabel, Pose2)
    addVariable!(dummyDfg, testVariableTwoLabel, Pose2)

    p1 = [randn(2) for _ in 1:50]
    P1 = manikde!(getManifold(Point2), p1)
    p2 = [randn(2) for _ in 1:50]
    P2 = manikde!(getManifold(Point2), p2)

    testFactor = ScatterAlignPose2(;cloud1=P1, cloud2=P2, sample_count=50, bw=1.0)
    addFactor!(dummyDfg,[testVariableOneLabel,testVariableTwoLabel], testFactor)
    packedData::String = JSON2.write(packFactor(dummyDfg, getFactor(dummyDfg,testLabel)))
    @debug packedData

    # Test add factor handler
    testDfg::AbstractDFG = initfg()
    addVariable!(testDfg, testVariableOneLabel, Pose2)
    addVariable!(testDfg, testVariableTwoLabel, Pose2)
    testAddFactorData::Dict{String,Any} = Dict(
        "userId" => "testUser",
        "robotId" => "testRobot",
        "sessionId" => "testSession",
        "packedData" => packedData
    )
    handler = addFactorHandlerConfig(testDfg)
    handler.handler(testAddFactorData)

    # Assert the factor was added to test dfg
    savedFactor = getFactor(testDfg,testLabel)
    return savedFactor !== nothing
end
